#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""

from pycatia.mec_mod_interfaces.boundary import Boundary


class Face(Boundary):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Reference
                |                         MecModInterfaces.Boundary
                |                             Face
                |
                | 2-D boundary.
                | Role: This Boundary object may be, for example, the lateral face of
                | cylinder.
                | You will create a Face object using the Shapes.GetBoundary ,
                | HybridShapes.GetBoundary , Sketches.GetBoundary or Selection.SelectElement2
                | method. Then, you pass it to the operator (such as
                | ShapeFactory.AddNewFaceFillet ).
                | The lifetime of a Face object is limited, see Boundary.
                | See also:
                | PlanarFace , CylindricalFace .
                |
                | Example:
                |     This example asks the end user to select two faces, and creates a face-face
                |     fillet on these faces:
                |
                |      Dim InputObjectType(0)
                |      Set Document = CATIA.ActiveDocument
                |      Set Selection = Document.Selection
                |      'We propose to the user that he select the first face
                |      InputObjectType(0)="Face"
                |      Status=Selection.SelectElement2(InputObjectType,"Select the first
                |      face",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set FirstFace = Selection.Item(1).Value
                |      Selection.Clear
                |      'We propose to the user that he select the second face
                |      InputObjectType(0)="Face"
                |      Status=Selection.SelectElement2(InputObjectType,"Select the second
                |      face",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set SecondFace = Selection.Item(1).Value
                |      Set FaceFillet = ShapeFactory.AddNewFaceFillet(FirstFace,SecondFace,5.0)
                |      Document.Part.Update

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.face = com_object

    def __repr__(self):
        return f'Face(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
from pycatia.system_interfaces.system_service import SystemService


class Point(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         Point
                | 
                | Represents the hybrid shape Point feature object.
                | Role: Declare hybrid shape Point root feature object. All interfaces for
                | different type of Point derives HybridShapePoint.
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapePoint
                | objects.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.point_ = com_object

    def get_coordinates(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetCoordinates(CATSafeArrayVariant oCoordinates)
                | 
                |     Gets cartesian coordinates of the Point.
                | 
                |     Parameters:
                | 
                |         oCoordinates
                |             coordinates of the Point.
                | 
                |     See also:
                |         HybridShapeFactory

        :return: tuple
        :rtype: tuple
        """
        vba_function_name = 'get_coordinates'
        vba_code = """
        Public Function get_coordinates(point)
            Dim oCoordinates (2)
            point.GetCoordinates oCoordinates
            get_coordinates = oCoordinates
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_coordinates(self, o_coordinates: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCoordinates(CATSafeArrayVariant oCoordinates)
                | 
                |     Sets cartesian coordinates of the point.
                |     Note: SetCoordinates can only be used on CATIAHybridShapePointCoord
                |     feature
                | 
                |     Parameters:
                | 
                |         iCoordinates
                |             coordinates of the point.
                | 
                |     See also:
                |         HybridShapeFactory

        :param tuple o_coordinates:
        :return: None
        :rtype: None
        """
        return self.point_.SetCoordinates(o_coordinates)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_coordinates'
        # # vba_code = """
        # # Public Function set_coordinates(point)
        # #     Dim oCoordinates (2)
        # #     point.SetCoordinates oCoordinates
        # #     set_coordinates = oCoordinates
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Point(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class CgrAdhesionSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         CGRAdhesionSettingAtt
                | 
                | Represents the base object to handle the parameters of the
                | cache.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cgr_adhesion_setting_att = com_object

    @property
    def v4_v5_fdt(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property V4V5_FDT() As boolean
                | 
                |     Retrieves the V4V5_FDT container activation state.

        :return: bool
        :rtype: bool
        """

        return self.cgr_adhesion_setting_att.V4V5_FDT

    @v4_v5_fdt.setter
    def v4_v5_fdt(self, value: bool):
        """
        :param bool value:
        """

        self.cgr_adhesion_setting_att.V4V5_FDT = value

    @property
    def v4_model_comment_page(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property V4_Model_CommentPage() As boolean
                | 
                |     Retrieves the V4_Model_CommentPage container activation state.

        :return: bool
        :rtype: bool
        """

        return self.cgr_adhesion_setting_att.V4_Model_CommentPage

    @v4_model_comment_page.setter
    def v4_model_comment_page(self, value: bool):
        """
        :param bool value:
        """

        self.cgr_adhesion_setting_att.V4_Model_CommentPage = value

    @property
    def v4_model_ln_f(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property V4_Model_LnF() As boolean
                | 
                |     Retrieves the V4_Model_LnF container activation state.

        :return: bool
        :rtype: bool
        """

        return self.cgr_adhesion_setting_att.V4_Model_LnF

    @v4_model_ln_f.setter
    def v4_model_ln_f(self, value: bool):
        """
        :param bool value:
        """

        self.cgr_adhesion_setting_att.V4_Model_LnF = value

    @property
    def v5_spa(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property V5_SPA() As boolean
                | 
                |     Retrieves the V5_SPA container activation state.

        :return: bool
        :rtype: bool
        """

        return self.cgr_adhesion_setting_att.V5_SPA

    @v5_spa.setter
    def v5_spa(self, value: bool):
        """
        :param bool value:
        """

        self.cgr_adhesion_setting_att.V5_SPA = value

    @property
    def voxels(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Voxels() As boolean
                | 
                |     Retrieves the Voxels container activation state.

        :return: bool
        :rtype: bool
        """

        return self.cgr_adhesion_setting_att.Voxels

    @voxels.setter
    def voxels(self, value: bool):
        """
        :param bool value:
        """

        self.cgr_adhesion_setting_att.Voxels = value

    def get_v4_v5_fdt_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetV4V5_FDTInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the V4V5_FDT container activation
                |     state.
                |     Refer to CATSysSettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.cgr_adhesion_setting_att.GetV4V5_FDTInfo(admin_level, o_locked)

    def get_v4_model_comment_page_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetV4_Model_CommentPageInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Locks or unlocks the V4_Model_CommentPage container activation
                |     state.
                |     Refer to CATSysSettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.cgr_adhesion_setting_att.GetV4_Model_CommentPageInfo(admin_level, o_locked)

    def get_v4_model_ln_f_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetV4_Model_LnFInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the V4_Model_LnF container activation
                |     state.
                |     Refer to CATSysSettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.cgr_adhesion_setting_att.GetV4_Model_LnFInfo(admin_level, o_locked)

    def get_v5_spa_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetV5_SPAInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the V5_SPA container activation
                |     state.
                |     Refer to CATSysSettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.cgr_adhesion_setting_att.GetV5_SPAInfo(admin_level, o_locked)

    def get_voxels_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetVoxelsInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Voxels container activation
                |     state.
                |     Refer to CATSysSettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.cgr_adhesion_setting_att.GetVoxelsInfo(admin_level, o_locked)

    def set_v4_v5_fdt_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetV4V5_FDTLock(boolean iLocked)
                | 
                |     Locks or unlocks the V4V5_FDT container activation state.
                |     Refer to CATSysSettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.cgr_adhesion_setting_att.SetV4V5_FDTLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_v4_v5_fdt_lock'
        # # vba_code = """
        # # Public Function set_v4_v5_fdt_lock(cgr_adhesion_setting_att)
        # #     Dim iLocked (2)
        # #     cgr_adhesion_setting_att.SetV4V5_FDTLock iLocked
        # #     set_v4_v5_fdt_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_v4_model_comment_page_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetV4_Model_CommentPageLock(boolean iLocked)
                | 
                |     Retrieves information about the V4_Model_CommentPage container activation
                |     state.
                |     Refer to CATSysSettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.cgr_adhesion_setting_att.SetV4_Model_CommentPageLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_v4_model_comment_page_lock'
        # # vba_code = """
        # # Public Function set_v4_model_comment_page_lock(cgr_adhesion_setting_att)
        # #     Dim iLocked (2)
        # #     cgr_adhesion_setting_att.SetV4_Model_CommentPageLock iLocked
        # #     set_v4_model_comment_page_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_v4_model_ln_f_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetV4_Model_LnFLock(boolean iLocked)
                | 
                |     Locks or unlocks the V4_Model_LnF container activation
                |     state.
                |     Refer to CATSysSettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.cgr_adhesion_setting_att.SetV4_Model_LnFLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_v4_model_ln_f_lock'
        # # vba_code = """
        # # Public Function set_v4_model_ln_f_lock(cgr_adhesion_setting_att)
        # #     Dim iLocked (2)
        # #     cgr_adhesion_setting_att.SetV4_Model_LnFLock iLocked
        # #     set_v4_model_ln_f_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_v5_spa_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetV5_SPALock(boolean iLocked)
                | 
                |     Locks or unlocks the V5_SPA container activation state.
                |     Refer to CATSysSettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.cgr_adhesion_setting_att.SetV5_SPALock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_v5_spa_lock'
        # # vba_code = """
        # # Public Function set_v5_spa_lock(cgr_adhesion_setting_att)
        # #     Dim iLocked (2)
        # #     cgr_adhesion_setting_att.SetV5_SPALock iLocked
        # #     set_v5_spa_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_voxels_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetVoxelsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Voxels container activation state.
                |     Refer to CATSysSettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.cgr_adhesion_setting_att.SetVoxelsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_voxels_lock'
        # # vba_code = """
        # # Public Function set_voxels_lock(cgr_adhesion_setting_att)
        # #     Dim iLocked (2)
        # #     cgr_adhesion_setting_att.SetVoxelsLock iLocked
        # #     set_voxels_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'CgrAdhesionSettingAtt(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.line import Line
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length


class HybridShapeLineAngle(Line):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Line
                |                             HybridShapeLineAngle
                | 
                | Line defined from a reference curve, a plane or a surface, a point and an
                | angle.
                | Role: Allows to access data of the the line feature created with an angle to a
                | curve.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_line_angle = com_object

    @property
    def angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Angle() As Angle (Read Only)
                | 
                |     Role: Get the angle to the reference curve of the line.
                | 
                |     Parameters:
                | 
                |         oAngle
                |             angle

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_line_angle.Angle)

    @property
    def begin_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BeginOffset() As Length (Read Only)
                | 
                |     Role: Get the start length of the line.
                | 
                |     Parameters:
                | 
                |         oStart
                |             start length

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_line_angle.BeginOffset)

    @property
    def curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Curve() As Reference
                | 
                |     Role: Get the reference curve.
                | 
                |     Parameters:
                | 
                |         oCurve
                |             reference curve.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_angle.Curve)

    @curve.setter
    def curve(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_line_angle.Curve = reference_curve.com_object

    @property
    def end_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndOffset() As Length (Read Only)
                | 
                |     Role: Get the end length of the line.
                | 
                |     Parameters:
                | 
                |         oEnd
                |             end length

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_line_angle.EndOffset)

    @property
    def geodesic(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Geodesic() As boolean
                | 
                |     Role: Get geodesic mode. If geodesic, the line lies on the support surface,
                |     otherwise the surface is only used to compute the line
                |     direction.
                | 
                |     Parameters:
                | 
                |         oGeod
                |             Geodesic boolean

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_line_angle.Geodesic

    @geodesic.setter
    def geodesic(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_line_angle.Geodesic = value

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Role: Get the line orientation. Orientation allows to reverse the line
                |     direction from the reference point. For a line of L length, it is the same as
                |     creating this line with -L length.
                | 
                |     Parameters:
                | 
                |         oOrientation
                |             orientation : can be 1 or -1

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_line_angle.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_line_angle.Orientation = value

    @property
    def point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Point() As Reference
                | 
                |     Role: Get the starting point of the line.
                | 
                |     Parameters:
                | 
                |         oPoint
                |             starting point.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_angle.Point)

    @point.setter
    def point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_line_angle.Point = reference_point.com_object

    @property
    def surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Surface() As Reference
                | 
                |     Role: Get the support surface.
                | 
                |     Parameters:
                | 
                |         oSurface
                |             support surface.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_angle.Surface)

    @surface.setter
    def surface(self, reference_surface: Reference):
        """
        :param Reference reference_surface:
        """

        self.hybrid_shape_line_angle.Surface = reference_surface.com_object

    def get_length_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLengthType() As long
                | 
                |     Gets the length type Default is 0.
                | 
                |     Parameters:
                | 
                |         oType
                |             The length type = 0 : length - the line is limited by its extremities =
                |             1 : infinite - the line is infinite = 2 : infinite start point - the line is infinite
                |             on the side of the start point = 3 : infinite end point - the line is infinite on the
                |             side of the end point

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_line_angle.GetLengthType()

    def get_symmetrical_extension(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSymmetricalExtension() As boolean
                | 
                |     Gets whether the symmetrical extension of the line is
                |     active.
                | 
                |     Parameters:
                | 
                |         oSym
                |             Symetry flag

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_line_angle.GetSymmetricalExtension()

    def set_length_type(self, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLengthType(long iType)
                | 
                |     Sets the length type Default is 0.
                | 
                |     Parameters:
                | 
                |         iType
                |             The length type = 0 : length - the line is limited by its extremities =
                |             1 : infinite - the line is infinite = 2 : infinite start point - the line is infinite on
                |             the side of the start point = 3 : infinite end point - the line is infinite on the side
                |             of the end point

        :param int i_type:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_line_angle.SetLengthType(i_type)

    def set_symmetrical_extension(self, i_sym: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSymmetricalExtension(boolean iSym)
                | 
                |     Sets the symmetrical extension of the line (start = -end).
                | 
                |     Parameters:
                | 
                |         iSym
                |             Symetry flag

        :param bool i_sym:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_line_angle.SetSymmetricalExtension(i_sym)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_symmetrical_extension'
        # # vba_code = """
        # # Public Function set_symmetrical_extension(hybrid_shape_line_angle)
        # #     Dim iSym (2)
        # #     hybrid_shape_line_angle.SetSymmetricalExtension iSym
        # #     set_symmetrical_extension = iSym
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeLineAngle(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class LightSource(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     LightSource
                | 
                | Represents the light source.
                | The light source is the object that stores lighting data used by a viewer to
                | display a scene where a document is presented. Two kinds of light sources are
                | available: an infinite light source and a neon lighting system simulating a set
                | of parallel neon tubes.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.light_source = com_object

    def get_direction(self, o_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDirection(CATSafeArrayVariant oDirection)
                | 
                |     Returns the lighting direction as an array of 3 variants. This value is
                |     available with an infinite light source only.
                | 
                |     Example:
                |         This example gets the lighting direction of the LightSource light
                |         source to the direction with components (5,8,-2).
                | 
                |          Dim direction(2)
                |          LightSource.GetDirection direction

        :param tuple o_direction:
        :return: None
        :rtype: None
        """
        return self.light_source.GetDirection(o_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_direction'
        # # vba_code = """
        # # Public Function get_direction(light_source)
        # #     Dim oDirection (2)
        # #     light_source.GetDirection oDirection
        # #     get_direction = oDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_direction(self, o_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutDirection(CATSafeArrayVariant oDirection)
                | 
                |     Defines the lighting direction as an array of 3 variants. This value can be
                |     set with an infinite light source only.
                | 
                |     Example:
                |         This example defines the lighting direction of the LightSource light
                |         source to the direction with components (5,8,-2).
                | 
                |          LightSource.PutDirection Array(5,8,-2)

        :param tuple o_direction:
        :return: None
        :rtype: None
        """
        return self.light_source.PutDirection(o_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_direction'
        # # vba_code = """
        # # Public Function put_direction(light_source)
        # #     Dim oDirection (2)
        # #     light_source.PutDirection oDirection
        # #     put_direction = oDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'LightSource(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeMidSurface(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeMidSurface
                | 
                | Represents the hybrid shape MidSurface feature object.
                | Role: To access the data of the hybrid shape MidSurface feature
                | object.
                | This data includes:
                | 
                |     Support Body
                |     Creation Mode
                |     Threshold Thickness
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeMidSurface
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_mid_surface = com_object

    @property
    def auto_thickness_threshold(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AutoThicknessThreshold() As long
                | 
                |     Returns or sets AutoThicknessThreshold. Automatic Thickmess Threshold Check Button ON :1,
                |     OFF : 0 (Only Automatic Creation Mode Available for Automation)

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_mid_surface.AutoThicknessThreshold

    @auto_thickness_threshold.setter
    def auto_thickness_threshold(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_mid_surface.AutoThicknessThreshold = value

    @property
    def creation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CreationMode() As long
                | 
                |     Returns or sets CreationMode. Face Pairs : 0, Faces To Offset : 1, Automatic :
                |     2 (Only Automatic Creation Mode Available for Automation)

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_mid_surface.CreationMode

    @creation_mode.setter
    def creation_mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_mid_surface.CreationMode = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets Support Body. Reference.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_mid_surface.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_mid_surface.Support = reference_support.com_object

    @property
    def threshold(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Threshold() As Length
                | 
                |     Returns or sets Threshold Thickness. Length.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_mid_surface.Threshold)

    @threshold.setter
    def threshold(self, value: Length):
        """
        :param Length value:
        """

        self.hybrid_shape_mid_surface.Threshold = value

    def __repr__(self):
        return f'HybridShapeMidSurface(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Publication(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Publication
                | 
                | The interface to access a CATIAPublication.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.publication = com_object

    @property
    def relay(self) -> 'Publication':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Relay(Publication iPub) (Write Only)
                | 
                |     Valuates a publication object with another publication object. Role: This
                |     method allows to valuate a publication with an intermediate
                |     one.
                | 
                |     Parameters:
                | 
                |         iPub
                |             The intermediate publication object
                | 
                |             Example: The following example valuates the publication object Pub1
                |             with the publication object Pub2
                | 
                |              Pub1.Relay(Pub2)

        :return: Publication
        :rtype: Publication
        """

        return self.publication.Relay

    @relay.setter
    def relay(self, publication: 'Publication'):
        """
        :param Publication publication:
        """

        self.publication.Relay = publication.com_object

    @property
    def valuation(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Valuation() As CATBaseDispatch
                | 
                |     Returns published object. Role: This method gives access to the finally
                |     published object.
                | 
                |     Parameters:
                | 
                |         oRef
                |             The final reference of the publication object.
                | 
                |             Example: This example returns the final reference Ref of the
                |             publication object Pub1.
                | 
                |              Dim Ref As Reference
                |              Ref = Pub1.Valuation

        :return: AnyObject
        :rtype: AnyObject
        """

        return AnyObject(self.publication.Valuation)

    @valuation.setter
    def valuation(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.publication.Valuation = value

    def __repr__(self):
        return f'Publication(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.viewer import Viewer
from pycatia.system_interfaces.collection import Collection


class Viewers(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Viewers
                | 
                | A collection of all the Viewer objects currently attached to a
                | window.
                | For a SpecsAndGeomWindow object, the viewer containing the geometry is the
                | first viewer, and the viewer containing the specification tree is the second
                | viewer.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Viewer)
        self.viewers = com_object

    def item(self, i_index: int) -> Viewer:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func Item(long iIndex) As Viewer
                | 
                |     Returns a viewer using its index from the Viewers collection. The first
                |     item has the rank 1 in the collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the viewer to retrieve from the collection
                |             of viewers. As a numerics, this index is the rank of the viewer in the
                |             collection. The index of the first viewer in the collection is 1, and the index
                |             of the last viewer is Count. As a string, it is the name you assigned to the
                |             viewer using the 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved viewer 
                | 
                | Example:
                |     This example returns in MyViewer the second viewer in the
                |     collection.
                | 
                |      Dim MyViewer As Viewer
                |      Set MyViewer = Viewer.Item(2)

        :param int i_index:
        :return: Viewer
        :rtype: Viewer
        """
        return Viewer(self.viewers.Item(i_index))

    def __getitem__(self, n: int) -> Viewer:
        if (n + 1) > self.count:
            raise StopIteration

        return Viewer(self.viewers.item(n + 1))

    def __iter__(self) -> Iterator[Viewer]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Viewers(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle


class HybridShapePlaneAngle(Plane):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlaneAngle
                | 
                | Represents the hybrid shape plane angle feature object.
                | Role: To access the data of the hybrid shape plane angle feature object,
                | created with an angle to another plane. This data includes:
                | 
                |     The rotation axis
                |     The rotation angle
                |     The reference plane
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapePlaneAngle
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_plane_angle = com_object

    @property
    def angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Angle() As Angle (Read Only)
                | 
                |     Returns the rotation angle.

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hybrid_shape_plane_angle.Angle)

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Returns or sets the plane orientation.
                |     Role: The orientation allows you to invert the plane from the reference
                |     plane.
                |     Legal values: the orientation is 1 if the plane orientation is not
                |     inverted, and -1 otherwise.

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_plane_angle.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_plane_angle.Orientation = value

    @property
    def plane(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Plane() As Reference
                | 
                |     Returns or sets the reference plane.
                |     Sub-element(s) supported (see Boundary object): PlanarFace.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane_angle.Plane)

    @plane.setter
    def plane(self, reference_plane: Reference):
        """
        :param Reference reference_plane:
        """

        self.hybrid_shape_plane_angle.Plane = reference_plane.com_object

    @property
    def projection_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProjectionMode() As boolean
                | 
                |     Gets or sets the projection mode status.
                |     ProjectionMode = TRUE : Rotation axis will be projected on to reference plane.
                |     FALSE(default) : Rotation axis will be as it is. This example retrieves in ProjMode the projection
                 |                     mode status for the PlaneAngle hybrid shape feature.
                | 
                |      Dim ProjMode As boolean
                |      ProjMode = PlaneAngle.ProjectionMode

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_plane_angle.ProjectionMode

    @projection_mode.setter
    def projection_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_plane_angle.ProjectionMode = value

    @property
    def revol_axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RevolAxis() As Reference
                | 
                |     Returns or sets the rotation axis.
                |     Sub-element(s) supported (see Boundary object): RectilinearTriDimFeatEdge,
                |     RectilinearBiDimFeatEdge or RectilinearMonoDimFeatEdge.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_plane_angle.RevolAxis)

    @revol_axis.setter
    def revol_axis(self, reference_axis: Reference):
        """
        :param Reference reference_axis:
        """

        self.hybrid_shape_plane_angle.RevolAxis = reference_axis.com_object

    def __repr__(self):
        return f'HybridShapePlaneAngle(name="{self.name}")'



#! /usr/bin/python3.6

"""

    The catia base object is from which most other functionality derives. See examples for more information.

    >>> from pycatia import catia
    >>> caa = catia()
    >>> documents = caa.documents
    >>> # documents represents the collection of currently open documents.
    >>> document = caa.active_document
    >>> # document is the currently active document.
    >>>
    >>> # open a new CATPart document
    >>> documents.add('Part')

"""

import os

from pycatia.base_interfaces.base_application import catia_application as catia
from pycatia.base_interfaces.context import CATIADocHandler
from .version import version

__author__ = 'Paul Bourne'
__author_email = 'evereux@gmail.com'
__description__ = 'A python module to access the CATIA Measurable object.'
__name__ = "pycatia"
__version__ = version
__url__ = "https://github.com/evereux/pycatia"

name = __name__



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeDevelop(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeDevelop
                | 
                | Represents the hybrid shape develop feature object.
                | Role: To access the data of the hybrid shape develop feature object. This data
                | includes:
                | 
                |     The developing mode
                |     The positining mode used for the 2D wire
                |     The 2D wire to be developed
                |     The positioning transformation
                |     The support revolution surface on which the development is
                |     operated
                |     The point designated as the origin of the planar 2D wire
                |     The direction corresponding to the first axis of the planar axis system
                |     related to the planar 2D wire
                |     The development origin on the support surface
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeDevelop
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_develop = com_object

    @property
    def mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Mode() As long
                | 
                |     Returns or sets the developing mode.
                |     Legal values:
                | 
                |     CATGSMDevelopMethod_DevDev
                |         Develop / develop algorithm
                |     CATGSMDevelopMethod_DevProj
                |         Develop / project algorithm

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_develop.Mode

    @mode.setter
    def mode(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_develop.Mode = value

    @property
    def mode_pos(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ModePos() As long
                | 
                |     Returns or sets the positioning mode used for the 2D wire.
                |     Legal values:
                | 
                |     CATGSMPositionMode_NoneOrPositioned
                |         No positioning 
                |     CATGSMPositionMode_ExplicitSweep
                |     CATGSMPositionMode_Develop
                |         The 2D wire is to be moved from its initial position

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_develop.ModePos

    @mode_pos.setter
    def mode_pos(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_develop.ModePos = value

    @property
    def plane_axis_direction(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneAxisDirection() As Reference
                | 
                |     Returns or sets the direction corresponding to the first axis of the planar
                |     axis system related to the planar 2D wire.
                |     Sub-element(s) supported (see Boundary object): RectilinearTriDimFeatEdge,
                |     BiDimFeatEdge or RectilinearMonoDimFeatEdge.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_develop.PlaneAxisDirection)

    @plane_axis_direction.setter
    def plane_axis_direction(self, reference_plane: Reference):
        """
        :param Reference reference_plane:
        """

        self.hybrid_shape_develop.PlaneAxisDirection = reference_plane.com_object

    @property
    def plane_axis_origin(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PlaneAxisOrigin() As Reference
                | 
                |     Returns or sets the point designated as the origin of the planar 2D
                |     wire.
                |     Sub-element(s) supported (see Boundary object): Vertex.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_develop.PlaneAxisOrigin)

    @plane_axis_origin.setter
    def plane_axis_origin(self, reference_plane: Reference):
        """
        :param reference_plane reference_plane:
        """

        self.hybrid_shape_develop.PlaneAxisOrigin = reference_plane.com_object

    @property
    def point_on_support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PointOnSupport() As Reference
                | 
                |     Returns or sets the development origin on the support
                |     surface.
                |     Sub-element(s) supported (see Boundary object): Vertex.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_develop.PointOnSupport)

    @point_on_support.setter
    def point_on_support(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_develop.PointOnSupport = reference_point.com_object

    @property
    def positioned_wire(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PositionedWire() As Reference
                | 
                |     Returns or sets the positioning transformation.
                |     Role: To retrieve or set the positioning transformation associated to the
                |     develop feature and which result corresponds to the positioned 2D wire.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_develop.PositionedWire)

    @positioned_wire.setter
    def positioned_wire(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_develop.PositionedWire = value.com_object

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support revolution surface on which the development is
                |     operated.
                |     Sub-element(s) supported (see Boundary object): Face.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_develop.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_develop.Support = reference_support.com_object

    @property
    def wire_to_develop(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property WireToDevelop() As Reference
                | 
                |     Returns or sets the 2D wire to be developed.
                |     Sub-element(s) supported (see Boundary object): TriDimFeatEdge or
                |     BiDimFeatEdge.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_develop.WireToDevelop)

    @wire_to_develop.setter
    def wire_to_develop(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.hybrid_shape_develop.WireToDevelop = reference.com_object

    def get_plane_axis_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPlaneAxisAngle() As Angle
                | 
                |     Retrieves the rotation angle.
                |     Role: The rotation angle is expressed in the planar coordinate system
                |     related to the 2D planar wire from its default position.
                | 
                |     Returns:
                |         The rotation value

        :return: Angle
        :rtype: Angle
        """
        return Angle(self.hybrid_shape_develop.GetPlaneAxisAngle())

    def get_plane_axis_coord(self, i_coor_idx: int) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPlaneAxisCoord(long iCoorIdx) As Length
                | 
                |     Retrieves the translation coordinates.
                |     Role: The translation coordinates are expressed with respect to the planar
                |     coordinate system related to the 2D planar wire from its default position.
                |     GetPlaneAxisCoord retrieves one coordinate at a time.
                | 
                |     Parameters:
                | 
                |         iCoorIdx
                |             The coordinate index
                |             Legal values
                |             : 1 for X and 2 for Y 
                | 
                |     Returns:
                |         The coordinate value

        :param int i_coor_idx:
        :return: Length
        :rtype: Length
        """
        return Length(self.hybrid_shape_develop.GetPlaneAxisCoord(i_coor_idx))

    def get_plane_axis_swap_axes(self, ii: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPlaneAxisSwapAxes(long ii) As long
                | 
                |     Retrieves the inversion axes from their previous
                |     definitions.
                | 
                |     Parameters:
                | 
                |         iI
                |             == NOT USED YET == Must always be set to 0 
                | 
                |     Returns:
                |         The inversion value
                |         Legal values:
                | 
                |         CATGSMAxisInversionMode_None
                |             No axis inverted 
                |         CATGSMAxisInversionMode_X
                |             Only the X axis is inverted
                |         CATGSMAxisInversionMode_Y
                |             Only the Y axis is inverted
                |         CATGSMAxisInversionMode_Both
                |             Both axes are inverted

        :param int ii:
        :return: int
        :rtype: int
        """
        return self.hybrid_shape_develop.GetPlaneAxisSwapAxes(ii)

    def set_plane_axis_angle(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPlaneAxisAngle(double iAngle)
                | 
                |     Sets the rotation angle.
                |     Role: The rotation angle is expressed in the planar coordinate system
                |     related to the 2D planar wire from its default position.
                | 
                |     Parameters:
                | 
                |         iAngle
                |             The rotation angle value.

        :param float i_angle:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_develop.SetPlaneAxisAngle(i_angle)

    def set_plane_axis_coord(self, i_coor_idx: int, i_coord_value: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPlaneAxisCoord(long iCoorIdx,
                | double iCoordValue)
                | 
                |     Sets the translation coordinates.
                |     Role: The translation coordinates are expressed with respect to the planar
                |     coordinate system related to the 2D planar wire from its default position.
                |     SetPlaneAxisCoord sets one coordinate at a time.
                | 
                |     Parameters:
                | 
                |         iCoorIdx
                |             The coordinate index
                |             Legal values
                |             : 1 for X and 2 for Y 
                |         iCoordValue
                |             The coordinate value

        :param int i_coor_idx:
        :param float i_coord_value:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_develop.SetPlaneAxisCoord(i_coor_idx, i_coord_value)

    def set_plane_axis_swap_axes(self, i_idx: int, i_inversion_value: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPlaneAxisSwapAxes(long iIdx,
                | long iInversionValue)
                | 
                |     Sets the inversion axes from their previous definitions.
                | 
                |     Parameters:
                | 
                |         iIdx
                |             == NOT USED YET == Must always be set to 0 
                |         iInversionValue
                |             The inversion value
                |             Legal values:
                | 
                |             CATGSMAxisInversionMode_None
                |                 No axis inverted 
                |             CATGSMAxisInversionMode_X
                |                 Only the X axis is inverted
                |             CATGSMAxisInversionMode_Y
                |                 Only the Y axis is inverted
                |             CATGSMAxisInversionMode_Both
                |                 Both axes are inverted

        :param int i_idx:
        :param int i_inversion_value:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_develop.SetPlaneAxisSwapAxes(i_idx, i_inversion_value)

    def __repr__(self):
        return f'HybridShapeDevelop(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.knowledge_interfaces.str_param import StrParam
from pycatia.part_interfaces.limit import Limit
from pycatia.part_interfaces.sketch_based_shape import SketchBasedShape


class Hole(SketchBasedShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SketchBasedShape
                |                             Hole
                | 
                | Hole Feature in Part Design.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hole = com_object

    @property
    def anchor_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AnchorMode() As CatHoleAnchorMode
                | 
                |     Returns the hole anchor mode.
                |     This information is pertinent when hole type is Counterbored or
                |     Counterdrilled only.
                | 
                |     Returns:
                |         oMode The hole anchor mode (see CatHoleAnchorMode for list of possible
                |         types)
                | 
                |         Example:
                |             The following example returns in holeAnchorMode the anchor mode of
                |             hole firstHole:
                | 
                |              Set holeAnchorMode = firstHole.AnchorMode

        :return: int
        :rtype: int
        """

        return self.hole.AnchorMode

    @anchor_mode.setter
    def anchor_mode(self, value: int):
        """
        :param int value:
        """

        self.hole.AnchorMode = value

    @property
    def bottom_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BottomAngle() As Angle (Read Only)
                | 
                |     Returns the hole bottom angle.
                |     This call is valid when the hole bottom type is : VBottom.
                | 
                |     Returns:
                |         oBottomAngle An Angle object controlling the hole bottom angle (see
                |         Angle for more information)
                | 
                |         Example:
                |             The following example returns in holeBottomAngle the bottom angle
                |             of hole firstHole:
                | 
                |              Set holeBottomAngle = firstHole.BottomAngle

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hole.BottomAngle)

    @property
    def bottom_limit(self) -> Limit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BottomLimit() As Limit (Read Only)
                | 
                |     Returns the bottom limit.
                |     This call is valid when the hole bottom type is : BlindHole or ThruHole.
                | 
                |     Returns:
                |         oBottomLimit A Limit object controlling the hole bottom limit (see
                |         Limit for more information)
                | 
                |         Example:
                |             The following example returns in holeBottomLimit the bottom limit
                |             of hole firstHole:
                | 
                |              Set holeBottomLimit = firstHole.BottomLimit

        :return: Limit
        :rtype: Limit
        """

        return Limit(self.hole.BottomLimit)

    @property
    def bottom_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BottomType() As CatHoleBottomType
                | 
                |     Returns the hole bottom type.
                | 
                |     Returns:
                |         oBottomType The hole bottom type (see CatHoleBottomType for list of
                |         possible types)
                | 
                |         Example:
                |             The following example returns in holeBottomType the bottom type of
                |             hole firstHole:
                | 
                |              Set holeBottomType = firstHole.BottomType

        :return: int
        :rtype: int
        """

        return self.hole.BottomType

    @bottom_type.setter
    def bottom_type(self, value: int):
        """
        :param int value:
        """

        self.hole.BottomType = value

    @property
    def counter_sunk_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CounterSunkMode() As CatCSHoleMode
                | 
                |     Returns the mode of a countersunk hole .
                | 
                |     Returns:
                |         CSMode Value of the countersunk mode (see CatCSHoleMode for list of
                |         possible types)
                | 
                |         Example:
                |             The following example returns in CSMode the CSMode of hole
                |             firsthole:
                | 
                |              Set CSMode = firsthole.CounterSunkMode

        :return: int
        :rtype: int
        """

        return self.hole.CounterSunkMode

    @counter_sunk_mode.setter
    def counter_sunk_mode(self, value: int):
        """
        :param int value:
        """

        self.hole.CounterSunkMode = value

    @property
    def diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Diameter() As Length (Read Only)
                | 
                |     Returns the hole diameter.
                | 
                |     Returns:
                |         oDiameter A Length object controlling the hole diameter (see Length for
                |         more information)
                | 
                |         Example:
                |             The following example returns in holeDiam the diameter of hole
                |             firstHole:
                | 
                |              Set holeDiam = firstHole.Diameter

        :return: Length
        :rtype: Length
        """

        return Length(self.hole.Diameter)

    @property
    def head_angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HeadAngle() As Angle (Read Only)
                | 
                |     Returns the hole head angle.
                |     This call is valid when the hole type is : Tapered or Counterdrilled or Countersunk.
                | 
                |     Returns:
                |         oHeadAngle An Angle object controlling the hole head angle (see Angle
                |         for more information)
                | 
                |         Example:
                |             The following example returns in holeHeadAngle the head angle of
                |             hole firstHole:
                | 
                |              Set holeHeadAngle = firstHole.HeadAngle

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.hole.HeadAngle)

    @property
    def head_depth(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HeadDepth() As Length (Read Only)
                | 
                |     Returns the hole head depth.
                |     This call is valid when the hole type is : Counterbored or Counterdrilled or Countersunk.
                | 
                |     Returns:
                |         oHeadDepth A Length object controlling the hole head depth (see Length
                |         for more information)
                | 
                |         Example:
                |             The following example returns in holeHeadDepth the head depth of
                |             hole firstHole:
                | 
                |              Set holeHeadDepth = firstHole.HeadDepth

        :return: Length
        :rtype: Length
        """

        return Length(self.hole.HeadDepth)

    @property
    def head_diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HeadDiameter() As Length (Read Only)
                | 
                |     Returns the hole head diameter.
                |     This call is valid when the hole type is : Counterbored or Counterdrilled.
                | 
                |     Returns:
                |         oHeadDiameter A Length object controlling the hole head diameter (see
                |         Length for more information)
                | 
                |         Example:
                |             The following example returns in holeHeadDiam the head diameter of
                |             hole firstHole:
                | 
                |              Set holeHeadDiam = firstHole.HeadDiameter

        :return: Length
        :rtype: Length
        """

        return Length(self.hole.HeadDiameter)

    @property
    def hole_thread_description(self) -> StrParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HoleThreadDescription() As StrParam (Read Only)
                | 
                |     Returns the hole thread description parameter.
                |     This call is valid when the hole threading mode is : CATThreadedHoleThreading.
                |     This call is valid only when a standard/user design table
                |     exists
                | 
                |     Returns:
                |         oThreadDescParam A Parameter object controlling the hole thread
                |         description (see StrParam for more information)
                | 
                |         Example:
                |             The following example returns in holeThreadDescription the thread
                |             description (M12 etc) of hole firstHole:
                | 
                |              Set holeThreadDescription = firstHole.HoleThreadDescription

        :return: StrParam
        :rtype: StrParam
        """

        return StrParam(self.hole.HoleThreadDescription)

    @property
    def thread_depth(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ThreadDepth() As Length (Read Only)
                | 
                |     Returns the hole thread depth.
                |     This call is valid when the hole threading mode is : CATThreadedHoleThreading.
                | 
                |     Returns:
                |         oThreadDepth A Length object controlling the hole thread depth (see
                |         Length for more information)
                | 
                |         Example:
                |             The following example returns in holeThreadDepth the thread depth
                |             of hole firstHole:
                | 
                |              Set holeThreadDepth = firstHole.ThreadDepth

        :return: Length
        :rtype: Length
        """

        return Length(self.hole.ThreadDepth)

    @property
    def thread_diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ThreadDiameter() As Length (Read Only)
                | 
                |     Returns the hole thread diameter.
                |     This call is valid when the hole threading mode is : CATThreadedHoleThreading.
                | 
                |     Returns:
                |         oThreadDiameter A Length object controlling the hole thread diameter
                |         (see Length for more information)
                | 
                |         Example:
                |             The following example returns in holeThreadDiameter the thread
                |             diameter of hole firstHole:
                | 
                |              Set holeThreadDiameter = firstHole.ThreadDiameter

        :return: Length
        :rtype: Length
        """

        return Length(self.hole.ThreadDiameter)

    @property
    def thread_pitch(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ThreadPitch() As Length (Read Only)
                | 
                |     Returns the hole thread pitch.
                |     This call is valid when the hole threading mode is : CATThreadedHoleThreading.
                | 
                |     Returns:
                |         oThreadPitch A Length object controlling the hole thread pitch (see
                |         Length for more information)
                | 
                |         Example:
                |             The following example returns in holeThreadPitch the thread pitch
                |             of hole firstHole:
                | 
                |              Set holeThreadPitch = firstHole.ThreadPitch

        :return: Length
        :rtype: Length
        """

        return Length(self.hole.ThreadPitch)

    @property
    def thread_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ThreadSide() As CatHoleThreadSide
                | 
                |     Returns the hole thread side.
                | 
                |     Returns:
                |         oThreadSide The hole thread side (see CatHoleThreadSide for list of
                |         possible sides)
                | 
                |         Example:
                |             The following example returns in holeThreadSide the thread side of
                |             hole firstHole:
                | 
                |              Set holeThreadSide = firstHole.ThreadSide

        :return: int
        :rtype: int
        """

        return self.hole.ThreadSide

    @thread_side.setter
    def thread_side(self, value: int):
        """
        :param int value:
        """

        self.hole.ThreadSide = value

    @property
    def threading_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ThreadingMode() As CatHoleThreadingMode
                | 
                |     Returns the hole threading mode.
                | 
                |     Returns:
                |         oThreadingMode The hole threading mode (see CatHoleThreadingMode for
                |         list of possible types)
                | 
                |         Example:
                |             The following example returns in holeThreadingMode the threading
                |             mode of hole firstHole:
                | 
                |              Set holeThreadingMode = firstHole.ThreadingMode

        :return: int
        :rtype: int
        """

        return self.hole.ThreadingMode

    @threading_mode.setter
    def threading_mode(self, value: int):
        """
        :param int value:
        """

        self.hole.ThreadingMode = value

    @property
    def type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Type() As CatHoleType
                | 
                |     Returns the hole type.
                | 
                |     Returns:
                |         oType The hole type (see CatHoleType for list of possible
                |         types)
                | 
                |         Example:
                |             The following example returns in holeType the type of hole
                |             firstHole:
                | 
                |              Set holeType = firstHole.Type

        :return: int
        :rtype: int
        """

        return self.hole.Type

    @type.setter
    def type(self, value: int):
        """
        :param int value:
        """

        self.hole.Type = value

    def create_standard_thread_design_table(self, i_standard_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub CreateStandardThreadDesignTable(CatHoleThreadStandard
                | iStandardType)
                | 
                |     Creates a Standard Thread design table .
                |     This call is valid when the hole threading mode is : CATThreadedHoleThreading.
                | 
                |     Parameters:
                | 
                |         iStandardType
                |             Standard type for thread (see 
                | 
                |         CatHoleThreadStandard for list of possible types)
                | 
                |         Example:
                |             The following example creates a standard table for MetricThinPitch
                |             for hole firstHole:
                | 
                |              firstHole.CreateStandardThreadDesignTable
                |              catHoleMetricThinPitch

        :param int i_standard_type:
        :return: None
        :rtype: None
        """
        return self.hole.CreateStandardThreadDesignTable(i_standard_type)

    def create_user_standard_design_table(self, i_standard_name: str, i_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub CreateUserStandardDesignTable(CATBSTR iStandardName,
                | CATBSTR iPath)
                | 
                |     Creates a UserStandard Thread design table .
                |     This call is valid when the hole threading mode is : CATThreadedHoleThreading.
                | 
                |     Parameters:
                | 
                |         iStandardName
                |             Name of the UserStandard thread. iStandardName should be empty if
                |             filepath is to be defined. 
                |         iPath
                |             Path of the UserStandard file. iPath is empty if the filepath is
                |             already defined through CATReffilesPath.
                | 
                |             Example1:
                |                 The following example creates a standard table for UserStandard
                |                 for hole firstHole. The file path is already defined thru
                |                 CATReffilesPath:
                | 
                |                  firstHole.CreateUserStandardDesignTable
                |                  "UserStandard",""
                | 
                |             Example2:
                |                 The following example creates a standard table for UserStandard
                |                 for hole firstHole when file path is not defined thru
                |                 CATReffilesPath:
                | 
                |                  firstHole.CreateUserStandardDesignTable
                |                  "","E:\\user\\standard\\UserStandard.txt"

        :param str i_standard_name:
        :param str i_path:
        :return: None
        :rtype: None
        """
        return self.hole.CreateUserStandardDesignTable(i_standard_name, i_path)

    def get_direction(self, io_direction: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetDirection(CATSafeArrayVariant ioDirection)
                | 
                |     Returns the hole direction with absolute coordinates.
                |     It provides a safe array with 3 elements : X, Y, Z direction coordinates
                | 
                |     Returns:
                |         oDirection The direction coordinates
                | 
                |         Example:
                |             The following example returns in dirArray the direction coordinates
                |             of hole firstHole:
                | 
                |              Call firstHole.GetDirection dirArray
                |              Set x = dirArray[1]
                |              Set y = dirArray[2]
                |              Set z = dirArray[3]

        :param tuple io_direction:
        :return: None
        :rtype: None
        """
        return self.hole.GetDirection(io_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_direction'
        # # vba_code = """
        # # Public Function get_direction(hole)
        # #     Dim ioDirection (2)
        # #     hole.GetDirection ioDirection
        # #     get_direction = ioDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_origin(self, io_origin: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetOrigin(CATSafeArrayVariant ioOrigin)
                | 
                |     Returns the origin point which the hole is anchored to.
                |     This point belongs to a tangent plane.
                | 
                |     Returns:
                |         oOrigin A Safe Array made up of 3 doubles : X, Y, Z - Hole origin point coordinates
                | 
                |         Example:
                |             The following example returns in coordArray the coordinates of hole
                |             firstHole:
                | 
                |              Call firstHole.GetOrigin coordArray
                |              Set x = coordArray[1]
                |              Set y = coordArray[2]
                |              Set z = coordArray[3]

        :param tuple io_origin:
        :return: None
        :rtype: None
        """
        return self.hole.GetOrigin(io_origin)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_origin'
        # # vba_code = """
        # # Public Function get_origin(hole)
        # #     Dim ioOrigin (2)
        # #     hole.GetOrigin ioOrigin
        # #     get_origin = ioOrigin
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reverse(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Reverse()
                | 
                |     Reverses the hole direction .
                | 
                |     Example:
                |         The following example reverses the current direction of hole
                |         firstHole:
                | 
                |          firstHole.Reverse()

        :return: None
        :rtype: None
        """
        return self.hole.Reverse()

    def set_direction(self, i_direction: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDirection(Reference iDirection)
                | 
                |     Sets the hole associative direction.
                | 
                |     Parameters:
                | 
                |         iDirection
                |             A Reference object to an edge or a line (see 
                | 
                |         Reference for more information)
                |         The following Boundary objects are supported:
                |         RectilinearTriDimFeatEdge, RectilinearBiDimFeatEdge and
                |         RectilinearMonoDimFeatEdge.
                | 
                |         Example:
                |             The following example sets the support direction of hole firstHole
                |             with holeDirRef direction reference :
                | 
                |              firstHole.SetDirection holeDirref

        :param Reference i_direction:
        :return: None
        :rtype: None
        """
        return self.hole.SetDirection(i_direction.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_direction'
        # # vba_code = """
        # # Public Function set_direction(hole)
        # #     Dim iDirection (2)
        # #     hole.SetDirection iDirection
        # #     set_direction = iDirection
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_origin(self, i_x: float, i_y: float, i_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetOrigin(double iX,
                | double iY,
                | double iZ)
                | 
                |     Sets the origin point which the hole is anchored to.
                |     If mandatory, the entry point will be projected onto a tangent
                |     plane.
                | 
                |     Parameters:
                | 
                |         iX
                |             Origin point x absolute coordinate 
                |         iY
                |             Origin point y absolute coordinate 
                |         iZ
                |             Origin point z absolute coordinate
                | 
                |             Example:
                |                 The following example sets the coordinates of hole firstHole to
                |                 10., 20., -5. :
                | 
                |                  firstHole.SetOrigin 10., 20., 5.

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :return: None
        :rtype: None
        """
        return self.hole.SetOrigin(i_x, i_y, i_z)

    def __repr__(self):
        return f'Hole(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""

from pycatia.in_interfaces.reference import Reference


class Boundary(Reference):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Reference
                |                         Boundary
                |
                | Topological cell, such as a face, an edge or a vertex.
                | Role: The Boundary objects are basic topological objects, such as the edge of a
                | Pad. Some of them posess a geometrical feature (planar face, rectilinear
                | edge).
                | You will create a Boundary object (such as the TriDimFeatEdge object, which is
                | derived, indirectly, from the Boundary object) using the Shapes.GetBoundary ,
                | HybridShapes.GetBoundary , Sketches.GetBoundary or Selection.SelectElement2
                | method. Then, you pass it to the operator (such as
                | ShapeFactory.AddNewEdgeFilletWithConstantRadius ). Note that, regarding V4
                | sub-elements, once the data of a CATIA Version 4 Model has been copied to a
                | .CATPart, the sub-elements of the resulting .CATPart are supported by the
                | Boundary object.
                | The lifetime of a Boundary object is limited. In particular, after having call
                | Part.Update , the Boundary objects are usually no more valid.
                | See also:
                |
                |     Face , PlanarFace , CylindricalFace
                |     Edge , TriDimFeatEdge , RectilinearTriDimFeatEdge , BiDimFeatEdge ,
                |     RectilinearBiDimFeatEdge , MonoDimFeatEdge ,
                |     RectilinearMonoDimFeatEdge
                |     Vertex , TriDimFeatVertexOrBiDimFeatVertex ,
                |     NotWireBoundaryMonoDimFeatVertex,
                |     ZeroDimFeatVertexOrWireBoundaryMonoDimFeatVertex
                |
                | Note: Boundary objects cannot be selected into the specification
                | tree.
                |
                | Note:For a Boundary object, the object returned by the AnyObject.Parent
                | property is the master shape. For example, if we have:
                |
                |                          Pad.2
                |                           !
                |                           !
                |  +                        V
                |  !                      +---+
                |  !                    /   / !
                |  +-- Pad.1          /   /   !
                |  !                /   / one +------+
                |  !               +---+    /       /! <--- Pad.1
                |  !               !   !  /       /  +
                |  +-- Pad.2       !   !/       /   /
                |                  !   +------+   /
                |                  !          ! /
                |                  +----------+
                |
                |
                | then, for the PlanarFace number "one", the AnyObject.Parent property returns
                | the Pad.2 automation object (see Pad ).
                |
                | Example:
                |     This example asks the end user to select an edge (using the TriDimFeatEdge
                |     object), and creates an edge fillet on this edge:
                |
                |      Dim InputObjectType(0)
                |      Set Document = CATIA.ActiveDocument
                |      Set Selection = Document.Selection
                |      'We propose to the user that he select an edge
                |      InputObjectType(0)="TriDimFeatEdge"
                |      Status=Selection.SelectElement2(InputObjectType,"Select an
                |      edge",true)
                |      if (Status = "cancel") then Exit Sub
                |      Set EdgeFillet = ShapeFactory.AddNewEdgeFilletWithConstantRadius(Selection.Item(1).Value,1,5.0)
                |      EdgeFillet.EdgePropagation = 1
                |      Document.Part.Update

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.boundary = com_object

    def __repr__(self):
        return f'Boundary(name="{self.name}")'



#! /usr/bin/python3.6

from win32com.client import Dispatch

from pycatia.in_interfaces.application import Application


def catia_application() -> Application:
    return Application(Dispatch('CATIA.Application'))



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.angle import Angle
from pycatia.part_interfaces.repartition import Repartition


class AngularRepartition(Repartition):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PartInterfaces.Repartition
                |                         AngularRepartition
                | 
                | Represents the angular repartition.
                | It is used by the circular pattern. It is made up of a number of times the
                | shape is copied and of an angular spacing between two consecutive copies of the
                | shape along a crown. The number of times the shape is copied is accessible
                | using the Repartition.InstancesCount property.
                | 
                | See also:
                |     CircPattern
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.angular_repartition = com_object

    @property
    def angular_spacing(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngularSpacing() As Angle (Read Only)
                | 
                |     Returns the angle between two consecutive copies of a shape along the
                |     repartition crown.
                | 
                |     Example:
                |         The following example returns in AngSpace1 the angular spacing of the
                |         angular repartition firstRepartition:
                | 
                |          Set AngSpace1 = firstRepartition.AngularSpacing

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.angular_repartition.AngularSpacing)

    @property
    def instance_spacing(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InstanceSpacing() As Angle (Read Only)
                | 
                |     Returns the angle at which the pattern spacing is done for unequal angular
                |     spacing mode.
                | 
                |     Example:
                |         The following example returns in AngSpace1 the angular spacing of the
                |         angular repartition firstRepartition:
                | 
                |          Set AngSpace1 = firstRepartition.AngularSpacing

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.angular_repartition.InstanceSpacing)

    def __repr__(self):
        return f'AngularRepartition(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeExtractMulti(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeExtractMulti
                | 
                | Represents the hybrid shape ExtractMulti feature object.
                | Role: To access the data of the hybrid shape ExtractMulti feature
                | object.
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeExtractMulti
                | object.
                | 
                | See also:
                |     HybridShapeFactory.AddNewExtractMulti
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_extract_multi = com_object

    def add_constraint(self, i_constraint: Reference, i_type: int, i_complementaire: bool, i_is_federated: bool,
                       i_crvtre_thsld: float, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddConstraint(Reference iConstraint,
                | long iType,
                | boolean iComplementaire,
                | boolean iIsFederated,
                | double iCrvtreThsld,
                | long iPos)
                | 
                |     Deprecated:
                |         V5R16 CATIAHybridShapeExtractMulti#AddConstraintTolerant Adds a
                |         constraint to the list of Extracted Elements. 
                |     Parameters:
                | 
                |         iConstraint
                |             The constraint to add. 
                |         iType
                |             the type of propagation for the ExtractMulti. 
                |         iComplementaire
                |             the Complementary flag checked/unchecked for for the constraint.
                |             
                |         iIsFederated
                |             the Federated flag checked/unchecked for the constraint.
                |             
                |         iCrvtreThsld
                |             the CurvatureThreshold for the constraint. 
                |         iPos
                |             The position at which the element is to be added in the list of
                |             constraints.
                | 
                |             Example:
                |                 This example adds a body in the list of constraints at
                |                 specified position with the type of propagation, the Federated flag and the
                |                 CurvatureThreshold of the HybShpExtractMulti hybrid shape
                |                 ExtractMulti.
                | 
                |                  Dim iType as long 
                |                  Dim iComplementaire as boolean 
                |                  Dim iIsFederated as boolean 
                |                  Dim iCrvtreThsld as double
                |                  HybShpExtractMulti.AddConstraint iCst  iType  iComplementaire
                |                  iIsFederated iCrvtreThsld  1

        :param Reference i_constraint:
        :param int i_type:
        :param bool i_complementaire:
        :param bool i_is_federated:
        :param float i_crvtre_thsld:
        :param int i_pos:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.AddConstraint(i_constraint.com_object, i_type, i_complementaire,
                                                             i_is_federated, i_crvtre_thsld, i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_constraint'
        # # vba_code = """
        # # Public Function add_constraint(hybrid_shape_extract_multi)
        # #     Dim iConstraint (2)
        # #     hybrid_shape_extract_multi.AddConstraint iConstraint
        # #     add_constraint = iConstraint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_constraint_tolerant(self, i_constraint: Reference, i_type: int, i_complementaire: bool,
                                i_is_federated: bool, i_distre_thsld: float, i_angtre_thsld: float,
                                i_crvtre_thsld: float, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddConstraintTolerant(Reference iConstraint,
                | long iType,
                | boolean iComplementaire,
                | boolean iIsFederated,
                | double iDistreThsld,
                | double iAngtreThsld,
                | double iCrvtreThsld,
                | long iPos)
                | 
                |     Adds a constraint to the list of Extracted Elements.
                | 
                |     Parameters:
                | 
                |         iConstraint
                |             The constraint to add. 
                |         iType
                |             the type of propagation for the ExtractMulti. 
                |         iComplementaire
                |             the Complementary flag checked/unchecked for for the constraint.
                |             
                |         iIsFederated
                |             the Federated flag checked/unchecked for the constraint.
                |             
                |         iDistreThsld
                |             the DistanceThreshold for the constraint. 
                |         iAngtreThsld
                |             the AngularThreshold for the constraint. 
                |         iCrvtreThsld
                |             the CurvatureThreshold for the constraint. 
                |         iPos
                |             The position at which the element is to be added in the list of
                |             constraints.
                | 
                |             Example:
                |                 This example adds a body in the list of constraints at
                |                 specified position with the type of propagation, the Federated flag and the
                |                 CurvatureThreshold of the HybShpExtractMulti hybrid shape
                |                 ExtractMulti.
                | 
                |                  Dim iType as long 
                |                  Dim iComplementaire as boolean 
                |                  Dim iIsFederated as boolean 
                |                  Dim iDistreThsld as double
                |                  Dim iAngtreThsld as double
                |                  Dim iCrvtreThsld as double
                |                  HybShpExtractMulti.AddConstraintTolerant iCst  iType 
                |                  iComplementaire iIsFederated iCrvtreThsld  1

        :param Reference i_constraint:
        :param int i_type:
        :param bool i_complementaire:
        :param bool i_is_federated:
        :param float i_distre_thsld:
        :param float i_angtre_thsld:
        :param float i_crvtre_thsld:
        :param int i_pos:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.AddConstraintTolerant(i_constraint.com_object, i_type, i_complementaire,
                                                                     i_is_federated, i_distre_thsld, i_angtre_thsld,
                                                                     i_crvtre_thsld, i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_constraint_tolerant'
        # # vba_code = """
        # # Public Function add_constraint_tolerant(hybrid_shape_extract_multi)
        # #     Dim iConstraint (2)
        # #     hybrid_shape_extract_multi.AddConstraintTolerant iConstraint
        # #     add_constraint_tolerant = iConstraint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_angular_threshold(self, i_pos: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAngularThreshold(long iPos) As double
                | 
                |     Returns the AngularThreshold of the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example retrieves the AngularThreshold in the list of constraints
                |         at specified position of the hybShpExtractMulti in
                |         AngularThH.
                | 
                |          Dim oAngtreThsld as double
                |          AngularThH = HybShpExtractMulti.GetAngularThreshold(1)

        :param int i_pos:
        :return: float
        :rtype: float
        """
        return self.hybrid_shape_extract_multi.GetAngularThreshold(i_pos)

    def get_angular_threshold_activity(self, i_pos: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetAngularThresholdActivity(long iPos) As boolean
                | 
                |     Returns the AngularThresholdActivity of the list of constraints at
                |     specified position.
                | 
                |     Example:
                |         This example retrieves the AngularThresholdActivity of the list of
                |         constraints at specified position of the hybShpExtractMulti in AngularActivity
                |         .
                | 
                |          Dim oAngtreThsldActivity as boolean 
                |          oAngtreThsldActivity  = HybShpExtractMulti.GetAngularThresholdActivity (1)

        :param int i_pos:
        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_extract_multi.GetAngularThresholdActivity(i_pos)

    def get_complementary_extract_multi(self, i_pos: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetComplementaryExtractMulti(long iPos) As boolean
                | 
                |     Returns the Complementary flag checked/unchecked of the list of constraints
                |     at specified position.
                | 
                |     Example:
                |         This example retrieves the Complementary flag in the list of
                |         constraints at specified position of the hybShpExtractMulti in
                |         Complementaire.
                | 
                |          Dim oComplementaire as boolean
                |          oComplementaire  = HybShpExtractMulti.GetComplementaryExtractMulti(1)

        :param int i_pos:
        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_extract_multi.GetComplementaryExtractMulti(i_pos)

    def get_curvature_threshold(self, i_pos: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCurvatureThreshold(long iPos) As double
                | 
                |     Returns the CurvatureThreshold of the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example retrieves the CurvatureThreshold in the list of
                |         constraints at specified position of the hybShpExtractMulti in
                |         CurvatureThH.
                | 
                |          Dim oCrvtreThsld as double
                |          CurvatureThH = HybShpExtractMulti.GetCurvatureThreshold(1)

        :param int i_pos:
        :return: float
        :rtype: float
        """
        return self.hybrid_shape_extract_multi.GetCurvatureThreshold(i_pos)

    def get_curvature_threshold_activity(self, i_pos: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetCurvatureThresholdActivity(long iPos) As boolean
                | 
                |     Returns the CurvatureThresholdActivity of the list of constraints at
                |     specified position.
                | 
                |     Example:
                |         This example retrieves the CurvatureThresholdActivity of the list of
                |         constraints at specified position of the hybShpExtractMulti in
                |         CurvatureActivity .
                | 
                |          Dim oCrvtreThsldActivity as boolean 
                |          oCrvtreThsldActivity  = HybShpExtractMulti.GetCurvatureThresholdActivity (1)

        :param int i_pos:
        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_extract_multi.GetCurvatureThresholdActivity(i_pos)

    def get_distance_threshold(self, i_pos: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDistanceThreshold(long iPos) As double
                | 
                |     Returns the DistanceThreshold of the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example retrieves the DistanceThreshold in the list of constraints
                |         at specified position of the hybShpExtractMulti in
                |         DistanceThH.
                | 
                |          Dim oDistreThsld as double
                |          DistanceThH = HybShpExtractMulti.GetDistanceThreshold(1)

        :param int i_pos:
        :return: float
        :rtype: float
        """
        return self.hybrid_shape_extract_multi.GetDistanceThreshold(i_pos)

    def get_distance_threshold_activity(self, i_pos: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDistanceThresholdActivity(long iPos) As boolean
                | 
                |     Returns the DistanceThresholdActivity of the list of constraints at
                |     specified position.
                | 
                |     Example:
                |         This example retrieves the DistanceThresholdActivity of the list of
                |         constraints at specified position of the hybShpExtractMulti in DistanceActivity
                |         .
                | 
                |          Dim oDistreThsldActivity as boolean 
                |          oDistreThsldActivity  = HybShpExtractMulti.GetDistanceThresholdActivity (1)

        :param int i_pos:
        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_extract_multi.GetDistanceThresholdActivity(i_pos)

    def get_element(self, i_pos: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetElement(long iPos) As Reference
                | 
                |     Returns the sub element used as init for the propagation.
                | 
                |     Example:
                |         This example retrieves the sub element in the list of constraints at
                |         specified position of the hybShpExtractMulti in Elem.
                | 
                |          Dim oElem as CATIAReference
                |          oElem = HybShpExtractMulti.GetElement(1)  
                |          
                | 
                |     See also:
                |         HybridShapeFactory

        :param int i_pos:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_extract_multi.GetElement(i_pos))

    def get_is_federated(self, i_pos: int) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetIsFederated(long iPos) As boolean
                | 
                |     Returns the IsFederated flag checked/unchecked of the list of constraints
                |     at specified position.
                | 
                |     Example:
                |         This example retrieves the federated flag in the list of constraints at
                |         specified position of the hybShpExtractMulti in
                |         IsFederated.
                | 
                |          Dim oIsFederated as boolean 
                |          oIsFederated  = HybShpExtractMulti.GetIsFederated(1)

        :param int i_pos:
        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_extract_multi.GetIsFederated(i_pos)

    def get_list_of_constraints(self, o_list_of_extracted_constraints: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetListOfConstraints(CATSafeArrayVariant
                | oListOfExtractedConstraints)
                | 
                |     Returns the list of Extracted Elements.
                | 
                |     Parameters:
                | 
                |         oListOfExtractedConstraints
                |             The list of constraints. It is returned as an array of
                |             nbconstraints in SafeArrayVariant.
                | 
                |             Example:
                |                 This example returns the list of constraints of the
                |                 HybShpExtractMulti hybrid shape ExtractMulti.
                | 
                |                  Dim oListOfExtractedConstraints as CATSafeArrayVariant
                |                  
                |                  HybShpExtractMulti.GetListOfConstraints
                |                  (oListOfExtractedConstraints) 
                |                  
                | 
                |                 Note: You can access each constraint as
                |                 follows:
                | 
                |                     1 is in oListOfExtractedConstraints(0)
                |                     2 is in oListOfExtractedConstraints(1)
                |                     nbconstraints is in
                |                     oListOfExtractedConstraints(nbconstraints-1)

        :param tuple o_list_of_extracted_constraints:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.GetListOfConstraints(o_list_of_extracted_constraints)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_constraints'
        # # vba_code = """
        # # Public Function get_list_of_constraints(hybrid_shape_extract_multi)
        # #     Dim oListOfExtractedConstraints (2)
        # #     hybrid_shape_extract_multi.GetListOfConstraints oListOfExtractedConstraints
        # #     get_list_of_constraints = oListOfExtractedConstraints
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_nb_constraints(self, o_nb_constraints: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetNbConstraints(long oNbConstraints)
                | 
                |     Returns number of constraints in the list of Extracted
                |     Elements.
                | 
                |     Parameters:
                | 
                |         oNbConstraints
                |             number of constraints in the list of Extracted
                |             Elements.
                | 
                |             Example:
                |                 This example returns number of constraints in the list of
                |                 constraints of the HybShpExtractMulti hybrid shape
                |                 ExtractMulti.
                | 
                |                  Dim oNbConstraints as long 
                |                  HybShpExtractMulti.GetNbConstraints (oNbConstraints )

        :param int o_nb_constraints:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.GetNbConstraints(o_nb_constraints)

    def get_propagation_type(self, i_pos: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPropagationType(long iPos) As long
                | 
                |     Returns the type of propagation of the list of constraints at specified
                |     position.
                |     The propagation types for the ExtractMulti can have the following
                |     values:
                | 
                |         1 for extraction propagation in point continuity
                |         2 for extraction propagation in tangent continuity
                |         3 for extraction without propagation
                |         4 for extraction propagation in curvature continuity
                | 
                |     Example:
                |         This example retrieves the PropagationType in the list of constraints
                |         at specified position of the hybShpExtractMulti in
                |         TypePropag.
                | 
                |          Dim oTypePropag as long 
                |          oTypePropag  = HybShpExtractMulti.GetPropagationType(1)

        :param int i_pos:
        :return: int
        :rtype: int
        """
        return self.hybrid_shape_extract_multi.GetPropagationType(i_pos)

    def get_support(self, i_pos: int) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSupport(long iPos) As Reference
                | 
                |     Returns the support of the list of constraints at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         oSupport
                |             The support.

        :param int i_pos:
        :return: Reference
        :rtype: Reference
        """
        return Reference(self.hybrid_shape_extract_multi.GetSupport(i_pos))

    def remove_element(self, i_position: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElement(long iPosition)
                | 
                |     Removes the body to be extracted from the list of constraints at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             Position at which the body is to be removed
                | 
                |             Example:
                |                 This example removes the body from the list of constraints at
                |                 specified position of the HybShpExtractMulti hybrid shape
                |                 ExtractMulti.
                | 
                |                  HybShpExtractMulti.RemoveElement  1

        :param int i_position:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.RemoveElement(i_position)

    def replace_element(self, i_extract_to_replace: Reference, i_new_extract: Reference, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplaceElement(Reference iExtractToReplace,
                | Reference iNewExtract,
                | long iPos)
                | 
                |     Replaces an element to extract in the list of constraints at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         iExtractToReplace
                |             The element to replace. 
                |         iNewExtract
                |             The new element. 
                |         iPos
                |             The position at which the element is to be replaced in the list of
                |             constraints.
                | 
                |             Example:
                |                 This example replaces the body from the list of constraints at
                |                 specified position of the HybShpExtractMulti hybrid shape
                |                 ExtractMulti.
                | 
                |                  Dim RefToRep  as CATIAReference
                |                  Dim RefNewExtract  as CATIAReference
                |                  HybShpExtractMulti.ReplaceElement RefToRep  RefNewExtract 1

        :param Reference i_extract_to_replace:
        :param Reference i_new_extract:
        :param int i_pos:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.ReplaceElement(i_extract_to_replace.com_object, i_new_extract.com_object,
                                                              i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_element'
        # # vba_code = """
        # # Public Function replace_element(hybrid_shape_extract_multi)
        # #     Dim iExtractToReplace (2)
        # #     hybrid_shape_extract_multi.ReplaceElement iExtractToReplace
        # #     replace_element = iExtractToReplace
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_angular_threshold(self, i_pos: int, i_angtre_thsld: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngularThreshold(long iPos,
                | double iAngtreThsld)
                | 
                |     Sets the AngularThreshold in the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example sets the AngularThreshold of the list of constraints at
                |         specified position of the hybShpExtractMulti in
                |         AngularThH.
                | 
                |          Dim iAngtreThsld as double
                |          HybShpExtractMulti.SetAngularThreshold 1 iAngtreThsld

        :param int i_pos:
        :param float i_angtre_thsld:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetAngularThreshold(i_pos, i_angtre_thsld)

    def set_angular_threshold_activity(self, i_pos: int, i_angtre_thsld_activity: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetAngularThresholdActivity(long iPos,
                | boolean iAngtreThsldActivity)
                | 
                |     Sets the AngularThresholdActivity in the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example sets the AngularThresholdActivity in the list of
                |         constraints at specified position of the hybShpExtractMulti in AngularActivity
                |         .
                | 
                |          Dim iAngtreThsldActivity as boolean 
                |          iAngtreThsldActivity = TRUE 
                |          HybShpExtractMulti.SetAngularThresholdActivity 1  iAngtreThsldActivity

        :param int i_pos:
        :param bool i_angtre_thsld_activity:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetAngularThresholdActivity(i_pos, i_angtre_thsld_activity)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_angular_threshold_activity'
        # # vba_code = """
        # # Public Function set_angular_threshold_activity(hybrid_shape_extract_multi)
        # #     Dim iPos (2)
        # #     hybrid_shape_extract_multi.SetAngularThresholdActivity iPos
        # #     set_angular_threshold_activity = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_complementary_extract_multi(self, i_pos: int, i_complementaire: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetComplementaryExtractMulti(long iPos,
                | boolean iComplementaire)
                | 
                |     Sets the Complementary flag checked/unchecked in the list of constraints at
                |     specified position.
                | 
                |     Example:
                |         This example sets the Complementary flag of the list of constraints at
                |         specified position of the hybShpExtractMulti in
                |         Complementaire.
                | 
                |          Dim iComplementaire as boolean
                |          iComplementaire  = TRUE 
                |          HybShpExtractMulti.SetComplementaryExtractMulti 1   iComplementaire

        :param int i_pos:
        :param bool i_complementaire:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetComplementaryExtractMulti(i_pos, i_complementaire)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_complementary_extract_multi'
        # # vba_code = """
        # # Public Function set_complementary_extract_multi(hybrid_shape_extract_multi)
        # #     Dim iPos (2)
        # #     hybrid_shape_extract_multi.SetComplementaryExtractMulti iPos
        # #     set_complementary_extract_multi = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_curvature_threshold(self, i_pos: int, i_crvtre_thsld: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCurvatureThreshold(long iPos,
                | double iCrvtreThsld)
                | 
                |     Sets the CurvatureThreshold in the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example sets the CurvatureThreshold of the list of constraints at
                |         specified position of the hybShpExtractMulti in
                |         CurvatureThH.
                | 
                |          Dim iCrvtreThsld as double
                |          HybShpExtractMulti.SetCurvatureThreshold 1 iCrvtreThsld

        :param int i_pos:
        :param float i_crvtre_thsld:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetCurvatureThreshold(i_pos, i_crvtre_thsld)

    def set_curvature_threshold_activity(self, i_pos: int, i_crvtre_thsld_activity: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetCurvatureThresholdActivity(long iPos,
                | boolean iCrvtreThsldActivity)
                | 
                |     Sets the CurvatureThresholdActivity in the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example sets the CurvatureThresholdActivity in the list of
                |         constraints at specified position of the hybShpExtractMulti in
                |         CurvatureActivity .
                | 
                |          Dim iCrvtreThsldActivity as boolean 
                |          iCrvtreThsldActivity = TRUE 
                |          HybShpExtractMulti.SetCurvatureThresholdActivity 1 
                |          iCrvtreThsldActivity

        :param int i_pos:
        :param bool i_crvtre_thsld_activity:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetCurvatureThresholdActivity(i_pos, i_crvtre_thsld_activity)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_curvature_threshold_activity'
        # # vba_code = """
        # # Public Function set_curvature_threshold_activity(hybrid_shape_extract_multi)
        # #     Dim iPos (2)
        # #     hybrid_shape_extract_multi.SetCurvatureThresholdActivity iPos
        # #     set_curvature_threshold_activity = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_distance_threshold(self, i_pos: int, i_distre_thsld: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDistanceThreshold(long iPos,
                | double iDistreThsld)
                | 
                |     Sets the DistanceThreshold in the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example sets the DistanceThreshold of the list of constraints at
                |         specified position of the hybShpExtractMulti in
                |         DistanceThH.
                | 
                |          Dim iDistreThsld as double
                |          HybShpExtractMulti.SetDistanceThreshold 1 iDistreThsld

        :param int i_pos:
        :param float i_distre_thsld:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetDistanceThreshold(i_pos, i_distre_thsld)

    def set_distance_threshold_activity(self, i_pos: int, i_distre_thsld_activity: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDistanceThresholdActivity(long iPos,
                | boolean iDistreThsldActivity)
                | 
                |     Sets the DistanceThresholdActivity in the list of constraints at specified
                |     position.
                | 
                |     Example:
                |         This example sets the DistanceThresholdActivity in the list of
                |         constraints at specified position of the hybShpExtractMulti in DistanceActivity
                |         .
                | 
                |          Dim iDistreThsldActivity as boolean 
                |          iDistreThsldActivity = TRUE 
                |          HybShpExtractMulti.SetDistanceThresholdActivity 1 
                |          iDistreThsldActivity

        :param int i_pos:
        :param bool i_distre_thsld_activity:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetDistanceThresholdActivity(i_pos, i_distre_thsld_activity)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_distance_threshold_activity'
        # # vba_code = """
        # # Public Function set_distance_threshold_activity(hybrid_shape_extract_multi)
        # #     Dim iPos (2)
        # #     hybrid_shape_extract_multi.SetDistanceThresholdActivity iPos
        # #     set_distance_threshold_activity = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_element(self, i_pos: int, i_elem: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetElement(long iPos,
                | Reference iElem)
                | 
                |     Sets the sub element used as init for the propagation.
                | 
                |     Example:
                |         This example sets the sub element in the list of constraints at
                |         specified position of the hybShpExtractMulti in Elem.
                | 
                |          Dim iPos as long 
                |          Dim iElem as CATIAReference
                |          HybShpExtractMulti.SetElement 1 iElem  
                |          
                | 
                |     See also:
                |         HybridShapeFactory

        :param int i_pos:
        :param Reference i_elem:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetElement(i_pos, i_elem.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_element'
        # # vba_code = """
        # # Public Function set_element(hybrid_shape_extract_multi)
        # #     Dim iPos (2)
        # #     hybrid_shape_extract_multi.SetElement iPos
        # #     set_element = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_is_federated(self, i_pos: int, i_is_federated: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetIsFederated(long iPos,
                | boolean iIsFederated)
                | 
                |     Sets the IsFederated flag checked/unchecked in the list of constraints at
                |     specified position.
                | 
                |     Example:
                |         This example sets the federated flag in the list of constraints at
                |         specified position of the hybShpExtractMulti in
                |         IsFederated.
                | 
                |          Dim iIsFederated as boolean 
                |           iIsFederated = TRUE 
                |          HybShpExtractMulti.SetIsFederated 1  iIsFederated

        :param int i_pos:
        :param bool i_is_federated:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetIsFederated(i_pos, i_is_federated)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_is_federated'
        # # vba_code = """
        # # Public Function set_is_federated(hybrid_shape_extract_multi)
        # #     Dim iPos (2)
        # #     hybrid_shape_extract_multi.SetIsFederated iPos
        # #     set_is_federated = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_propagation_type(self, i_pos: int, i_type_propag: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPropagationType(long iPos,
                | long iTypePropag)
                | 
                |     Sets the type of propagation for the ExtractMulti in the list of
                |     constraints at specified position.
                |     The propagation types for the ExtractMulti can have the following
                |     values:
                | 
                |         1 for extraction propagation in point continuity
                |         2 for extraction propagation in tangent continuity
                |         3 for extraction without propagation
                |         4 for extraction propagation in curvature continuity
                | 
                |     Example:
                |         This example sets the PropagationType of the list of constraints at
                |         specified position of the hybShpExtractMulti in
                |         TypePropag.
                | 
                |          Dim iTypePropag as long 
                |          iTypePropag = 1 
                |          HybShpExtractMulti.SetPropagationType 1 iTypePropag

        :param int i_pos:
        :param int i_type_propag:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetPropagationType(i_pos, i_type_propag)

    def set_support(self, i_pos: int, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSupport(long iPos,
                | Reference iSupport)
                | 
                |     Sets the support of the list of constraints at specified
                |     position.
                | 
                |     Parameters:
                | 
                |         oSupport
                |             The support.

        :param int i_pos:
        :param Reference i_support:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_extract_multi.SetSupport(i_pos, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_support'
        # # vba_code = """
        # # Public Function set_support(hybrid_shape_extract_multi)
        # #     Dim iPos (2)
        # #     hybrid_shape_extract_multi.SetSupport iPos
        # #     set_support = iPos
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeExtractMulti(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.dress_up_shape import DressUpShape


class Thickness(DressUpShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             Thickness
                | 
                | Represents the thickness shape.
                | The thickness shape is made up of a collection of faces to process and an
                | offset parameter.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.thickness = com_object

    @property
    def faces_to_thicken(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FacesToThicken() As References (Read Only)
                | 
                |     Returns the collection of faces to be thickened.
                | 
                |     Example:
                |         The following example returns in list the list of faces of the
                |         thickness firstThickness:
                | 
                |          Set list = firstThickness.FacesToThicken

        :return: References
        :rtype: References
        """

        return References(self.thickness.FacesToThicken)

    @property
    def offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Offset() As Length (Read Only)
                | 
                |     Returns the thickness offset.
                | 
                |     Example:
                |         The following example returns in offset the offset of the thickness
                |         firstThickness:
                | 
                |          Set offset = firstThickness.Offset

        :return: Length
        :rtype: Length
        """

        return Length(self.thickness.Offset)

    def add_face_to_thicken(self, i_face_to_thicken: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceToThicken(Reference iFaceToThicken)
                | 
                |     Adds a new face to be thickened.
                | 
                |     Parameters:
                | 
                |         iFaceToThicken
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example adds the new face face to thicken for the thickness
                |     firstThickness:
                | 
                |      call firstThickness.AddFaceToThicken(face)

        :param Reference i_face_to_thicken:
        :return: None
        :rtype: None
        """
        return self.thickness.AddFaceToThicken(i_face_to_thicken.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_to_thicken'
        # # vba_code = """
        # # Public Function add_face_to_thicken(thickness)
        # #     Dim iFaceToThicken (2)
        # #     thickness.AddFaceToThicken iFaceToThicken
        # #     add_face_to_thicken = iFaceToThicken
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_face_with_different_thickness(self, i_face_to_thicken: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddFaceWithDifferentThickness(Reference
                | iFaceToThicken)
                | 
                |     Adds a new face to thicken with a different offset value.
                | 
                |     Parameters:
                | 
                |         iFaceToThicken
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example adds the new face face to thicken with a different
                |     offset value for the thickness firstThickness:
                | 
                |      call firstThickness.AddFaceWithDifferentThickness(face)

        :param Reference i_face_to_thicken:
        :return: None
        :rtype: None
        """
        return self.thickness.AddFaceWithDifferentThickness(i_face_to_thicken.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_face_with_different_thickness'
        # # vba_code = """
        # # Public Function add_face_with_different_thickness(thickness)
        # #     Dim iFaceToThicken (2)
        # #     thickness.AddFaceWithDifferentThickness iFaceToThicken
        # #     add_face_with_different_thickness = iFaceToThicken
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_face_with_different_thickness(self, i_face_to_remove: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveFaceWithDifferentThickness(Reference
                | iFaceToRemove)
                | 
                |     Removes an existing thickened face.
                | 
                |     Parameters:
                | 
                |         iFaceToRemove
                |             The face to remove
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example removes the existing face thickened face from the
                |     thickness firstThickness:
                | 
                |      call

        :param Reference i_face_to_remove:
        :return: None
        :rtype: None
        """
        return self.thickness.RemoveFaceWithDifferentThickness(i_face_to_remove.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_face_with_different_thickness'
        # # vba_code = """
        # # Public Function remove_face_with_different_thickness(thickness)
        # #     Dim iFaceToRemove (2)
        # #     thickness.RemoveFaceWithDifferentThickness iFaceToRemove
        # #     remove_face_with_different_thickness = iFaceToRemove
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_volume_support(self, i_volume_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetVolumeSupport(Reference iVolumeSupport)
                | 
                |     Set support of Thickness feature.

        :param Reference i_volume_support:
        :return: None
        :rtype: None
        """
        return self.thickness.SetVolumeSupport(i_volume_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_volume_support'
        # # vba_code = """
        # # Public Function set_volume_support(thickness)
        # #     Dim iVolumeSupport (2)
        # #     thickness.SetVolumeSupport iVolumeSupport
        # #     set_volume_support = iVolumeSupport
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def withdraw_face_to_thicken(self, i_face_to_withdraw: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub WithdrawFaceToThicken(Reference iFaceToWithdraw)
                | 
                |     Withdraws an existing thickened face.
                | 
                |     Parameters:
                | 
                |         iFaceToWithdraw
                |             The face to withdraw
                |             The following 
                | 
                |         Boundary object is supported: Face. 
                | 
                | Example:
                |     The following example withdraws the existing face thickened face from the
                |     thickness firstThickness:
                | 
                |      call firstThickness.WithdrawFaceToThicken(face)

        :param Reference i_face_to_withdraw:
        :return: None
        :rtype: None
        """
        return self.thickness.WithdrawFaceToThicken(i_face_to_withdraw.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'withdraw_face_to_thicken'
        # # vba_code = """
        # # Public Function withdraw_face_to_thicken(thickness)
        # #     Dim iFaceToWithdraw (2)
        # #     thickness.WithdrawFaceToThicken iFaceToWithdraw
        # #     withdraw_face_to_thicken = iFaceToWithdraw
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Thickness(name="{self.name}")'
